==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AAndBinop.h <==
// public final class soot.jimple.parser.node.AAndBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 325b4952753319c7 soot_jimple_parser_node_AAndBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AAndBinop_H_
#define _JC_soot_jimple_parser_node_AAndBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TAnd$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AAndBinop$sub_refs	_jc_soot_jimple_parser_node_AAndBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AAndBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AAndBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AAndBinop$refs	_jc_soot_jimple_parser_node_AAndBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AAndBinop$nonrefs	_jc_soot_jimple_parser_node_AAndBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AAndBinop$object	_jc_soot_jimple_parser_node_AAndBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AAndBinop$vmethods	_jc_soot_jimple_parser_node_AAndBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AAndBinop$vtable	_jc_soot_jimple_parser_node_AAndBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AAndBinop$vtype	_jc_soot_jimple_parser_node_AAndBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AAndBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *);
extern void _jc_soot_jimple_parser_node_AAndBinop$method$_init$7cbc7f462887eda5(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_soot_jimple_parser_node_TAnd$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AAndBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AAndBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *);
extern struct _jc_soot_jimple_parser_node_TAnd$object *_jc_soot_jimple_parser_node_AAndBinop$method$getAnd$44c5822d30a16739(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *);
extern void _jc_soot_jimple_parser_node_AAndBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AAndBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AAndBinop$method$setAnd$6a2e0b01c769f473(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_soot_jimple_parser_node_TAnd$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AAndBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AAndBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AAndBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AAndBinop$method_info$getAnd$44c5822d30a16739;
extern _jc_method _jc_soot_jimple_parser_node_AAndBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AAndBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AAndBinop$method_info$setAnd$6a2e0b01c769f473;
extern _jc_method _jc_soot_jimple_parser_node_AAndBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AAndBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *);
	struct _jc_soot_jimple_parser_node_TAnd$object	*(*getAnd$44c5822d30a16739)(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setAnd$6a2e0b01c769f473)(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_soot_jimple_parser_node_TAnd$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AAndBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AAndBinop$vmethods	soot_jimple_parser_node_AAndBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AAndBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AAndBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AAndBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TAnd$object	*__5fand__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AAndBinop$refs {
    _jc_soot_jimple_parser_node_AAndBinop$sub_refs	soot_jimple_parser_node_AAndBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AAndBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AAndBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AAndBinop$sub_nonrefs	soot_jimple_parser_node_AAndBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AAndBinop$object {
	_jc_soot_jimple_parser_node_AAndBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AAndBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AAndBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AAndBinop$vtype _jc_soot_jimple_parser_node_AAndBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AAndBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AAndBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AAndBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AAndBinop.h <==
// public final class soot.jimple.parser.node.AAndBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 325b4952753319c7 soot_jimple_parser_node_AAndBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_AAndBinop_H_
#define _JC_soot_jimple_parser_node_AAndBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TAnd$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AAndBinop$sub_refs	_jc_soot_jimple_parser_node_AAndBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AAndBinop$sub_nonrefs	_jc_soot_jimple_parser_node_AAndBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AAndBinop$refs	_jc_soot_jimple_parser_node_AAndBinop$refs;
typedef struct _jc_soot_jimple_parser_node_AAndBinop$nonrefs	_jc_soot_jimple_parser_node_AAndBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AAndBinop$object	_jc_soot_jimple_parser_node_AAndBinop$object;

typedef const struct _jc_soot_jimple_parser_node_AAndBinop$vmethods	_jc_soot_jimple_parser_node_AAndBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AAndBinop$vtable	_jc_soot_jimple_parser_node_AAndBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_AAndBinop$vtype	_jc_soot_jimple_parser_node_AAndBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AAndBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AAndBinop$method$_init$7cbc7f462887eda5(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_soot_jimple_parser_node_TAnd$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AAndBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AAndBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TAnd$object *_jc_soot_jimple_parser_node_AAndBinop$method$getAnd$44c5822d30a16739(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AAndBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AAndBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AAndBinop$method$setAnd$6a2e0b01c769f473(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_soot_jimple_parser_node_TAnd$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AAndBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AAndBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AAndBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AAndBinop$method_info$getAnd$44c5822d30a16739;
extern _jc_method _jc_soot_jimple_parser_node_AAndBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AAndBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AAndBinop$method_info$setAnd$6a2e0b01c769f473;
extern _jc_method _jc_soot_jimple_parser_node_AAndBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AAndBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TAnd$object	*(*getAnd$44c5822d30a16739)(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setAnd$6a2e0b01c769f473)(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *, struct _jc_soot_jimple_parser_node_TAnd$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AAndBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AAndBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_AAndBinop$vmethods	soot_jimple_parser_node_AAndBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_AAndBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AAndBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AAndBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TAnd$object	*__5fand__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AAndBinop$refs {
    _jc_soot_jimple_parser_node_AAndBinop$sub_refs	soot_jimple_parser_node_AAndBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AAndBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AAndBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_AAndBinop$sub_nonrefs	soot_jimple_parser_node_AAndBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AAndBinop$object {
	_jc_soot_jimple_parser_node_AAndBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AAndBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_AAndBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AAndBinop$vtype _jc_soot_jimple_parser_node_AAndBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AAndBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AAndBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_AAndBinop_H_ */
